@@ -14,6 +14,7 @@ from .proto.cosmos.base.tendermint.v1beta1 import (
     query_pb2_grpc as tendermint_query_grpc,
     query_pb2 as tendermint_query,
 )
+
 from .proto.cosmos.auth.v1beta1 import (
     query_pb2_grpc as auth_query_grpc,
     query_pb2 as auth_query,
@@ -142,6 +143,12 @@ class AsyncClient:
             start=True
         )
 
+    async def get_tx(self, tx_hash):
+        return await self.stubTx.GetTx(
+            tx_service.GetTxRequest(
+                hash=tx_hash )
+        )
+
     async def close_exchange_channel(self):
         await self.exchange_channel.close()
 
@@ -581,10 +588,12 @@ class AsyncClient:
 
     async def get_spot_trades(self, market_id: str, **kwargs):
         req = spot_exchange_rpc_pb.TradesRequest(
-            market_id=market_id,
+            market_id=kwargs.get("market_id"),
+            market_ids=kwargs.get("market_ids"),
             execution_side=kwargs.get("execution_side"),
             direction=kwargs.get("direction"),
             subaccount_id=kwargs.get("subaccount_id"),
+            subaccount_ids=kwargs.get("subaccount_ids"),
             skip=kwargs.get("skip"),
             limit=kwargs.get("limit"),
         )
@@ -681,8 +690,10 @@ class AsyncClient:
 
     async def get_derivative_trades(self, market_id: str, **kwargs):
         req = derivative_exchange_rpc_pb.TradesRequest(
-            market_id=market_id,
+            market_id=kwargs.get("market_id"),
+            market_ids=kwargs.get("market_ids"),
             subaccount_id=kwargs.get("subaccount_id"),
+            subaccount_ids=kwargs.get("subaccount_ids"),
             execution_side=kwargs.get("execution_side"),
             direction=kwargs.get("direction"),
             skip=kwargs.get("skip"),
@@ -797,4 +808,3 @@ class AsyncClient:
     async def get_binary_options_market(self, market_id: str):
         req = derivative_exchange_rpc_pb.BinaryOptionsMarketRequest(market_id=market_id)
         return await self.stubDerivativeExchange.BinaryOptionsMarket(req)
-    
\ No newline at end of file
