@@ -146,7 +146,7 @@ class Network:
     @classmethod
     def local(cls):
         return cls(
-            lcd_endpoint='localhost:10337',
+            lcd_endpoint='http://localhost:10337',
             grpc_endpoint='localhost:9900',
             grpc_exchange_endpoint='localhost:9910',
             chain_id='injective-1',
